pub struct Mesh {
pub vertices: Vec<Vertex>,
pub indices: Vec<u32>,
}Expand description
A simple mesh type that holds a vector of vertices and another one of indices.
This type is meant to be converted to your own mesh type via the std::convert::From trait.
Fields
vertices: Vec<Vertex>The vertices of the mesh.
indices: Vec<u32>The vertex indices of the mesh.